.. _debops.freeradius:

debops.freeradius
=================

`FreeRADIUS <https://freeradius.org/>`__ is a RADIUS (Remote Authentication
Dial-In User Service) server. It can be used to set up Authorization,
Authentication nd Accounting (AAA) services on a wired or wireless network.

The ``debops.freeradius`` Ansible role can be used to install and configure
FreeRADIUS server on a Debian/Ubuntu hosts.

.. toctree::
   :maxdepth: 2

   getting-started
   defaults/main
   defaults-detailed
   example-eduroam

Copyright
---------

.. literalinclude:: ../../../../ansible/roles/debops.freeradius/COPYRIGHT

..
 Local Variables:
 mode: rst
 ispell-local-dictionary: "american"
 End:
